##  Overview
The onboarding guide for enterprise architects streamlines the process of onboarding into SAP LeanIX Application Portfolio Management, offering step-by-step guidance, relevant resources, and progress tracking through best practice metrics. The guide provides enablement content for each onboarding step and enables you to efficiently track your progress on task completion right in the application.
**Note**
The onboarding guide is available as part of the Application Portfolio Management Onboarding Dashboard for enterprise architects in versions 2 and 3.
  * Version 3: Available in all new workspaces and for self-service activation starting February 4, 2026.
  * Version 2: Available in all new workspaces starting June 6, 2024, and for self-service activation in all workspaces starting August 12, 2024.


For more information, see [Application Portfolio Management Onboarding Dashboard for Enterprise Architects](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD "The Application Portfolio Management Onboarding Dashboard for enterprise architects streamlines the process of onboarding to SAP LeanIX Application Portfolio Management.").
Onboarding Guide for SAP LeanIX Application Portfolio Management![Onboarding Guide for Application Portfolio Management](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4c15666c2a7243e299e981313c5ca708_LowRes.png)
